iris-grib
=========

|Travis|_ |Coveralls|_

GRIB interface for `Iris <https://github.com/SciTools/iris>`_.

Code
----
iris-grib is licenced under the GNU Lesser General Public License (LGPLv3).

The full text of the licence can be found in the COPYING and COPYING.LESSER
files.

Copyright and licence
---------------------

\(C) British Crown Copyright 2010 - 2016, Met Office

This file is part of iris-grib.

iris-grib is free software: you can redistribute it and/or modify it under
the terms of the GNU Lesser General Public License as published by the
Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

iris-grib is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with iris-grib.  If not, see `<http://www.gnu.org/licenses/>`_.

.. |Travis| image:: https://travis-ci.org/SciTools/iris-grib.svg?branch=master
.. _Travis: https://travis-ci.org/SciTools/iris-grib

.. |Coveralls| image:: https://coveralls.io/repos/github/SciTools/iris-grib/badge.svg?branch=master
.. _Coveralls: https://coveralls.io/github/SciTools/iris-grib?branch=master 
